@@ -5,12 +5,15 @@
 # A module to access data from the DFG-funded SPP Computational Literary Studies
 #
 # Usage:
-# import cls
-# df = cls.DataFrame("judenbuche", ["events", "keypassages"])
+# from sppcls import sppcls
+# df = sppcls.load_df("judenbuche", ["events", "keypassages"])
 #
 # Author: rja
 #
 # Changes:
+# 2022-08-26 (rja)
+# - fixed usage example
+# - fixed column name (s/word/token/)
 # 2022-08-25 (rja)
 # - initial version
 
@@ -19,7 +22,7 @@ import pandas as pd
 # default repository URL
 SPP_CLS_GITLAB = "https://cls-gitlab.phil.uni-wuerzburg.de/spp-cls-data-exchange/spp-cls_annotationtables_data/-/raw/main/"
 
-
+# FIXME: do we want to support more/all pandas.DataFrame kwargs?
 def load_df(work, projects, repository=SPP_CLS_GITLAB, na_values=""):
     """Generates a dataframe with the data of the projects for work."""
     dataframes = [_download(work, p, repository, na_values) for p in projects]
@@ -38,7 +41,7 @@ def _merge(dataframes, projects):
     """Merge the dataframes using a JOIN."""
     dataframe = dataframes[0]
     for df in dataframes[1:]:
-        dataframe = pd.merge(dataframe, df, on=["id", "word"], suffixes=_suffixes(projects))
+        dataframe = pd.merge(dataframe, df, on=["id", "token"], suffixes=_suffixes(projects))
     return dataframe
 
 
